==> v2.2.0.zip: info_tren/lib/pages/train_info_page/view_train/train_info_cupertino_DisplayTrainStation.dart <==
import 'package:flutter/cupertino.dart';
import 'package:info_tren/models/train_data.dart';
import 'package:info_tren/pages/train_info_page/train_info_constants.dart';

class DisplayTrainStation extends StatelessWidget {
  final Station station;

  DisplayTrainStation({required this.station});

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisSize: MainAxisSize.min,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: <Widget>[
        Row(
          mainAxisSize: MainAxisSize.max,
          children: <Widget>[
            Builder(
              builder: (context) {
                final delay = station.departure?.status?.delay ?? station.arrival?.status?.delay;
                final real = station.departure?.status?.real ?? station.arrival?.status?.real;

                final isDelayed = delay != null && delay > 0 && real == true;
                final isOnTime = delay != null && delay <= 0 && real == true;
                final isNotScheduled = false;

                return KmBadge(
                  station: station,
                  isNotScheduled: isNotScheduled,
                  isDelayed: isDelayed,
                  isOnTime: isOnTime,
                );
              }
            ),
            Expanded(
              child: Title(
                station: station,
              ),
            )
          ],
        ),
        Time(
          station: station,
        ),
        Delay(
          station: station,
        ),
      ],
    );
  }
}

class KmBadge extends StatelessWidget {
  final Station station;
  final bool isNotScheduled;
  final bool isOnTime;
  final bool isDelayed;

  KmBadge({
    required this.station,
    this.isNotScheduled = false,
    this.isOnTime = false,
    this.isDelayed = false,
  });

  @override
  Widget build(BuildContext context) {
    Color foregroundColor = FOREGROUND_WHITE;
    Color? backgroundColor;

    if (isNotScheduled) {
      foregroundColor = Color.fromRGBO(225, 175, 30, 1);
      backgroundColor = Color.fromRGBO(80, 40, 10, 1);
    }
    else if (isOnTime) {
      foregroundColor = Color.fromRGBO(130, 175, 65, 1);
      backgroundColor = Color.fromRGBO(40, 80, 10, 1);
    }
    else if (isDelayed) {
      foregroundColor = Color.fromRGBO(225, 75, 30, 1);
      backgroundColor = Color.fromRGBO(80, 20, 10, 1);
    }

    return Padding(
      padding: const EdgeInsets.all(8),
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
          border: Border.all(
            width: 2,
            color: foregroundColor,
          ),
          color: backgroundColor,
          // color: CupertinoColors.activeOrange,
        ),
        width: 48,
        height: 48,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Expanded(
              child: Center(
                child:  Text(
                  station.km.toString(),
                  style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                    fontSize: 20,
                    fontWeight: MediaQuery.of(context).boldText ? FontWeight.w400 : FontWeight.w200,
                    color: MediaQuery.of(context).boldText ? FOREGROUND_WHITE : foregroundColor,
                  ),
                  textAlign: TextAlign.center,
                ),
              ),
            ),
            Text(
              "km",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                fontSize: 10,
                color: MediaQuery.of(context).boldText ? FOREGROUND_WHITE : foregroundColor,
              ),
            ),
          ],
        ),
      ),
    );
  }
}

class Title extends StatelessWidget {
  final Station station;

  Title({
    required this.station
  });

  @override
  Widget build(BuildContext context) {
    return Text(
      station.name,
      style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
        fontSize: 22,
        fontWeight: MediaQuery.of(context).boldText ? FontWeight.w500 : FontWeight.w300,
        // fontStyle: items[1] == "ONI" ? FontStyle.italic : FontStyle.normal,
      ),
      textAlign: TextAlign.center,
    );
  }
}

class Time extends StatelessWidget {
  final Station station;

  Time({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival == null) {
      // Plecare
      return DepartureTime(
        station: station,
        firstStation: true,
      );
    }

    if (station.departure == null) {
      // Sosire
      return ArrivalTime(
        station: station,
        finalStation: true,
      );
    }

    return Row(
      crossAxisAlignment: CrossAxisAlignment.center,
      children: <Widget>[
        Text(
          "→",
          style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
            fontSize: 22,
          ),
        ),
        Container(width: 2,),
        ArrivalTime(station: station,),
        Expanded(child: Container(),),
        StopTime(station: station,),
        Expanded(child: Container(),),
        DepartureTime(station: station,),
        Container(width: 2,),
        Text(
          "→",
          style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
            fontSize: 22,
          ),
        ),
      ],
    );
  }
}

class ArrivalTime extends StatelessWidget {
  final Station station;
  final bool finalStation;

  ArrivalTime({
    required this.station,
    this.finalStation = false,
  });

  @override
  Widget build(BuildContext context) {
    if (finalStation) {
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Text(
            "→",
            style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
              fontSize: 22,
            ),
          ),
          Container(width: 2,),
          Text("sosire la "),
          ArrivalTime(station: station,),
          Expanded(child: Container(),),
        ],
      );
    }
    else {
      final delay = station.arrival!.status?.delay ?? 0;
      final time = station.arrival!.scheduleTime;

      if (delay == 0) {
        return Text("$time");
      }
      else if (delay > 0) {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                color: CupertinoColors.destructiveRed,
              ),
            ),
          ],
        );
      }
      else {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.subtract(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                color: CupertinoColors.activeGreen,
              ),
            ),
          ],
        );
      }
    }
  }
}

class StopTime extends StatelessWidget {
  final Station station;

  StopTime({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    final stopsFor = station.stoppingTime!;
    return Column(
      mainAxisSize: MainAxisSize.min,
      children: <Widget>[
        Text(
          "staționează pentru",
          textAlign: TextAlign.center,
        ),
        Builder(
          builder: (context) {
            int stopsForInt = stopsFor;
            if (stopsForInt == 1) {
              return Text(
                "1 minut",
                textAlign: TextAlign.center,
              );
            }
            else if (stopsForInt < 20) {
              return Text(
                "$stopsFor minute",
                textAlign: TextAlign.center,
              );
            }
            else {
              return Text(
                "$stopsFor de minute",
                textAlign: TextAlign.center,
              );
            }
          },
        )
      ],
    );
  }
}

class DepartureTime extends StatelessWidget {
  final Station station;
  final bool firstStation;

  DepartureTime({
    required this.station,
    this.firstStation = false,
  });

  @override
  Widget build(BuildContext context) {
    if (firstStation) {
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Expanded(child: Container(),),
          Text("plecare la "),
          DepartureTime(station: station,),
          Container(width: 2,),
          Text(
            "→",
            style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
              fontSize: 22,
            ),
          ),
        ],
      );
    }
    else {
      final delay = station.departure!.status?.delay ?? 0;
      final time = station.departure!.scheduleTime;

      if (delay == 0) {
        return Text("$time");
      }
      else if (delay > 0) {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                color: CupertinoColors.destructiveRed,
              ),
            ),
          ],
        );
      }
      else {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.subtract(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                color: CupertinoColors.activeGreen,
              ),
            ),
          ],
        );
      }
    }
  }
}

class Delay extends StatelessWidget {
  final Station station;

  Delay({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival?.status == null && station.departure?.status == null) {
      return Container();
    }
    var delay = station.arrival?.status?.delay;
    if (station.departure?.status?.real == true) {
      delay = station.departure?.status?.delay;
    }

    if (delay == 0 || delay == null) return Container();
    else if (delay > 0) {
      return Text(
        "$delay minute întârziere",
        style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
          color: CupertinoColors.destructiveRed,
          fontSize: 14,
          fontStyle: FontStyle.italic,
        ),
      );
    }
    else if (delay < 0) {
      return Text(
        "${-delay} minute mai devreme",
        style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
          color: CupertinoColors.activeGreen,
          fontSize: 14,
          fontStyle: FontStyle.italic,
        ),
      );
    }

    return Container();
  }
}

==> v2.3.1.zip: info_tren/lib/pages/train_info_page/view_train/train_info_cupertino_DisplayTrainStation.dart <==
import 'package:flutter/cupertino.dart';
import 'package:info_tren/models/train_data.dart';
import 'package:info_tren/pages/train_info_page/train_info_constants.dart';

class DisplayTrainStation extends StatelessWidget {
  final Station station;

  DisplayTrainStation({required this.station});

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisSize: MainAxisSize.min,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: <Widget>[
        Row(
          mainAxisSize: MainAxisSize.max,
          children: <Widget>[
            Builder(
              builder: (context) {
                final departureStatus = station.departure?.status;
                final arrivalStatus = station.arrival?.status;
                int delay;
                bool real;
                if (departureStatus == null) {
                  delay = arrivalStatus?.delay ?? 0;
                  real = arrivalStatus?.real ?? false;
                }
                else if (arrivalStatus == null) {
                  delay = departureStatus.delay;
                  real = departureStatus.real;
                }
                else {
                  delay = departureStatus.delay;
                  real = departureStatus.real;
                  if (!real && arrivalStatus.real) {
                    delay = arrivalStatus.delay;
                    real = arrivalStatus.real;
                  }
                }

                final isDelayed = delay > 0 && real == true;
                final isOnTime = delay <= 0 && real == true;
                final isNotScheduled = false;

                return KmBadge(
                  station: station,
                  isNotScheduled: isNotScheduled,
                  isDelayed: isDelayed,
                  isOnTime: isOnTime,
                );
              }
            ),
            Expanded(
              child: Title(
                station: station,
              ),
            )
          ],
        ),
        Time(
          station: station,
        ),
        Delay(
          station: station,
        ),
      ],
    );
  }
}

class KmBadge extends StatelessWidget {
  final Station station;
  final bool isNotScheduled;
  final bool isOnTime;
  final bool isDelayed;

  KmBadge({
    required this.station,
    this.isNotScheduled = false,
    this.isOnTime = false,
    this.isDelayed = false,
  });

  @override
  Widget build(BuildContext context) {
    Color foregroundColor = FOREGROUND_WHITE;
    Color? backgroundColor;

    if (isNotScheduled) {
      foregroundColor = Color.fromRGBO(225, 175, 30, 1);
      backgroundColor = Color.fromRGBO(80, 40, 10, 1);
    }
    else if (isOnTime) {
      foregroundColor = Color.fromRGBO(130, 175, 65, 1);
      backgroundColor = Color.fromRGBO(40, 80, 10, 1);
    }
    else if (isDelayed) {
      foregroundColor = Color.fromRGBO(225, 75, 30, 1);
      backgroundColor = Color.fromRGBO(80, 20, 10, 1);
    }

    return Padding(
      padding: const EdgeInsets.all(8),
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
          border: Border.all(
            width: 2,
            color: foregroundColor,
          ),
          color: backgroundColor,
          // color: CupertinoColors.activeOrange,
        ),
        width: 48,
        height: 48,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Expanded(
              child: Center(
                child:  Text(
                  station.km.toString(),
                  style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                    fontSize: 20,
                    fontWeight: MediaQuery.of(context).boldText ? FontWeight.w400 : FontWeight.w200,
                    color: MediaQuery.of(context).boldText ? FOREGROUND_WHITE : foregroundColor,
                  ),
                  textAlign: TextAlign.center,
                ),
              ),
            ),
            Text(
              "km",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                fontSize: 10,
                color: MediaQuery.of(context).boldText ? FOREGROUND_WHITE : foregroundColor,
              ),
            ),
          ],
        ),
      ),
    );
  }
}

class Title extends StatelessWidget {
  final Station station;

  Title({
    required this.station
  });

  @override
  Widget build(BuildContext context) {
    return Text(
      station.name,
      style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
        fontSize: 22,
        fontWeight: MediaQuery.of(context).boldText ? FontWeight.w500 : FontWeight.w300,
        // fontStyle: items[1] == "ONI" ? FontStyle.italic : FontStyle.normal,
      ),
      textAlign: TextAlign.center,
    );
  }
}

class Time extends StatelessWidget {
  final Station station;

  Time({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival == null) {
      // Plecare
      return DepartureTime(
        station: station,
        firstStation: true,
      );
    }

    if (station.departure == null) {
      // Sosire
      return ArrivalTime(
        station: station,
        finalStation: true,
      );
    }

    return Row(
      crossAxisAlignment: CrossAxisAlignment.center,
      children: <Widget>[
        Text(
          "→",
          style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
            fontSize: 22,
          ),
        ),
        Container(width: 2,),
        ArrivalTime(station: station,),
        Expanded(child: Container(),),
        StopTime(station: station,),
        Expanded(child: Container(),),
        DepartureTime(station: station,),
        Container(width: 2,),
        Text(
          "→",
          style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
            fontSize: 22,
          ),
        ),
      ],
    );
  }
}

class ArrivalTime extends StatelessWidget {
  final Station station;
  final bool finalStation;

  ArrivalTime({
    required this.station,
    this.finalStation = false,
  });

  @override
  Widget build(BuildContext context) {
    if (finalStation) {
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Text(
            "→",
            style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
              fontSize: 22,
            ),
          ),
          Container(width: 2,),
          Text("sosire la "),
          ArrivalTime(station: station,),
          Expanded(child: Container(),),
        ],
      );
    }
    else {
      final delay = station.arrival!.status?.delay ?? 0;
      final time = station.arrival!.scheduleTime;

      if (delay == 0) {
        return Text("$time");
      }
      else if (delay > 0) {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                color: CupertinoColors.destructiveRed,
              ),
            ),
          ],
        );
      }
      else {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                color: CupertinoColors.activeGreen,
              ),
            ),
          ],
        );
      }
    }
  }
}

class StopTime extends StatelessWidget {
  final Station station;

  StopTime({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    final stopsFor = station.stoppingTime!;
    return Column(
      mainAxisSize: MainAxisSize.min,
      children: <Widget>[
        Text(
          "staționează pentru",
          textAlign: TextAlign.center,
        ),
        Builder(
          builder: (context) {
            int stopsForInt = stopsFor;
            if (stopsForInt == 1) {
              return Text(
                "1 minut",
                textAlign: TextAlign.center,
              );
            }
            else if (stopsForInt < 20) {
              return Text(
                "$stopsFor minute",
                textAlign: TextAlign.center,
              );
            }
            else {
              return Text(
                "$stopsFor de minute",
                textAlign: TextAlign.center,
              );
            }
          },
        )
      ],
    );
  }
}

class DepartureTime extends StatelessWidget {
  final Station station;
  final bool firstStation;

  DepartureTime({
    required this.station,
    this.firstStation = false,
  });

  @override
  Widget build(BuildContext context) {
    if (firstStation) {
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Expanded(child: Container(),),
          Text("plecare la "),
          DepartureTime(station: station,),
          Container(width: 2,),
          Text(
            "→",
            style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
              fontSize: 22,
            ),
          ),
        ],
      );
    }
    else {
      final delay = station.departure!.status?.delay ?? 0;
      final time = station.departure!.scheduleTime;

      if (delay == 0) {
        return Text("$time");
      }
      else if (delay > 0) {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                color: CupertinoColors.destructiveRed,
              ),
            ),
          ],
        );
      }
      else {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
                color: CupertinoColors.activeGreen,
              ),
            ),
          ],
        );
      }
    }
  }
}

class Delay extends StatelessWidget {
  final Station station;

  Delay({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival?.status == null && station.departure?.status == null) {
      return Container();
    }
    var delay = station.arrival?.status?.delay;
    if (station.departure?.status?.real == true) {
      delay = station.departure?.status?.delay;
    }

    if (delay == 0 || delay == null) return Container();
    else if (delay > 0) {
      return Text(
        "$delay minute întârziere",
        style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
          color: CupertinoColors.destructiveRed,
          fontSize: 14,
          fontStyle: FontStyle.italic,
        ),
      );
    }
    else if (delay < 0) {
      return Text(
        "${-delay} minute mai devreme",
        style: CupertinoTheme.of(context).textTheme.textStyle.copyWith(
          color: CupertinoColors.activeGreen,
          fontSize: 14,
          fontStyle: FontStyle.italic,
        ),
      );
    }

    return Container();
  }
}
